@@ -38,6 +38,8 @@ private slots:
     void processReturnValue(int Id,QVariant data);
     void error(int i,QString string);
     void fault(int i,int j,QString string);
+    //! Enable and disable OK button.
+    void allowOkButton();
 
 signals:
     //! Emitted if login succesful.
