@@ -24,19 +24,9 @@ QtIrreco::QtIrreco(QWidget *parent)
     connect(this,SIGNAL(remoteDeleted()),lw,SLOT(clearScreen()));
 
     useModeEnabled = true;
-    
-    QUrl url;
-    url.setHost("mercury.wipsl.com");
-    url.setPath("/qtirreco/webdb/");
-    url.setPort(80);
 
-    client = new QxtXmlRpcClient(this, url);
-    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
-    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
-    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
-
-    this->checkForRemotes();
-    if(remoteNames->count() != 0) {
+   this->checkForRemotes();
+   if(remoteNames->count() != 0) {
        this->setWindowTitle("QtIrreco:"+activeRemote);
        this->setActiveRemote();
     }
@@ -307,7 +297,6 @@ void QtIrreco::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePres
 }
 void QtIrreco::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number,int timeOut)
 {
-    Q_UNUSED(number);
     lw->addButton(fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, QPoint(0,0), timeOut);
 }
 
@@ -476,7 +465,6 @@ void QtIrreco::downloadDB()
     DownloadUserRemoteDlg *downloadDlg = new DownloadUserRemoteDlg(this);
     connect(downloadDlg,SIGNAL(remoteDownloaded(QString)),this,SLOT(addDownloadedRemote(QString)));
     downloadDlg->exec();
-    delete downloadDlg;
 }
 
 void QtIrreco::uploadDB()
@@ -852,6 +840,16 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
         }
     }
 
+    QUrl url;
+    url.setHost("mercury.wipsl.com");
+    url.setPath("/qtirreco/webdb/");
+    url.setPort(80);
+
+    client = new QxtXmlRpcClient(this, url);
+    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
+    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
+    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
+
     if(themesForRemote.isEmpty()) {
         lw->setActiveRemoteName(activeRemote);
         this->writeRemoteChanges();
@@ -957,6 +955,16 @@ void QtIrreco::checkLircFilesForRemote(QString remoteFile)
         }
     }
 
+    QUrl url;
+    url.setHost("mercury.wipsl.com");
+    url.setPath("/qtirreco/webdb/");
+    url.setPort(80);
+
+    client = new QxtXmlRpcClient(this, url);
+    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
+    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
+    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
+
     QList<QVariant> params;
     for(callCounter=0;callCounter<lircConfs.length();callCounter++) {
         QMessageBox::information(this,"Lirc configuration","Configuration " + lircConfs.at(callCounter) + " downloaded succesfully!",
@@ -978,7 +986,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         themeDatas = client->call("getThemeById",params);
 
     }
-    else if (Id == themeDatas) {
+    if (Id == themeDatas) {
         QMap<QString,QVariant> array = data.toMap();
         QVariant name = array.value("name");
         themeNameFromConf = name.toString();
@@ -1000,12 +1008,12 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         params.append(downloadId);
         themeButtonIds = client->call("getButtons",params);
     }
-    else if (Id == themeButtonIds) {
+    if (Id == themeButtonIds) {
         dbButtonIdsList = sList;
         this->getThemeButtonsByIds();
 
     }
-    else if (Id == buttonData) { // COPY BUTTONS AND MAKE FOLDERS
+    if (Id == buttonData) { // COPY BUTTONS AND MAKE FOLDERS
 
         progressValue += 100 / (dbButtonIdsList.count()+2);
         emit progressState(progressValue);
@@ -1064,7 +1072,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         // Get button imagedatas and make .png files
         this->getUnpressedImage();
     }
-    else if (Id == unpressedToFile)  { // Name always unpressed.png
+    if (Id == unpressedToFile)  { // Name always unpressed.png
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1072,7 +1080,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(buttonPath+"/unpressed.png","PNG");
         this->getPressedImage();
     }
-    else if (Id == pressedToFile) { // Name always pressed.png
+    if (Id == pressedToFile) { // Name always pressed.png
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1080,7 +1088,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(buttonPath+"/pressed.png","PNG");
         this->getThemeButtonsByIds();
     }
-    else if (Id == themeBgIds) {
+    if (Id == themeBgIds) {
         dbBackgroundIdsList = sList;
         if(dbBackgroundIdsList.count() > 0 && !dbBackgroundIdsList.contains("0")) {
             this->setWindowTitle("Downloading theme backgrounds...");
@@ -1091,7 +1099,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
             this->downloadTheme();
         }
     }
-    else if (Id == bgData) {
+    if (Id == bgData) {
         themeBgIndex++;
         progressValue += 100 / (dbButtonIdsList.count()+2);
         emit progressState(progressValue);
@@ -1116,7 +1124,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         // Get background imagedatas and make .png files
         this->getBgImage();
     }
-    else if (Id == bgToFile) {
+    if (Id == bgToFile) {
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1124,7 +1132,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(bgPath+"/image.png","PNG");
         this->getThemeBackgroundsByIds();
     }
-    else if (Id == fileId) {
+    if (Id == fileId) {
         if(!QFile::exists(devicesPath + lircConfs.at(callCounter-1))) {
             QFile deviceFile(devicesPath +lircConfs.at(callCounter-1));
             deviceFile.open(QIODevice::WriteOnly | QIODevice::Text);
@@ -1172,14 +1180,13 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
 
 void QtIrreco::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error: "+QString::number(i,10),string,
+    QMessageBox::warning(this,"Error",string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 
 void QtIrreco::fault(int i,int j,QString string)
 {
-    Q_UNUSED(j);
-    QMessageBox::warning(this,"Fault: "+QString::number(i,10), string,
+    QMessageBox::warning(this,"Fault",string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void QtIrreco::getUnpressedImage()
