@@ -66,7 +66,7 @@ private:
     //! Method to change background.
     void changeBackground(QString backgroundName,QColor backgroundColor);
     //! Method to read remotes config file.
-    void readRemoteFile(QString line);
+    void readRemoteFile(QString line, bool lastLine);
     //! When renaming,deleting or changing active remote.
     void writeRemoteChanges();
     //! When no remotes found on device.
