@@ -6,11 +6,16 @@ ThemeManager::ThemeManager(QWidget *parent) :
     m_ui(new Ui::ThemeManager)
 {
     m_ui->setupUi(this);
+    remoteStartup = false;
     m_ui->commentTextEdit->setProperty("FingerScrollable", true);
-    this->setWindowTitle("Theme manager");
+
+    if(this->parent()->objectName() != "remoteStartupDlg") {
+        this->setWindowTitle("Theme manager");
+        m_ui->listWidget->addItem("Device");
+        m_ui->listWidget->addItem("Database");
+    }
+
     m_ui->downloadPushButton->setDisabled(true);
-    m_ui->listWidget->addItem("Device");
-    m_ui->listWidget->addItem("Database");
     m_ui->previousPushButton->setDisabled(true);
     m_ui->deletePushButton->setDisabled(true);
     connect(m_ui->listWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(updateListWidget(QListWidgetItem*)));
@@ -368,16 +373,22 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
              emit themeLoaded();
              QMessageBox::information(this,"Theme manager","Theme downloaded succesfully.",
                                      QMessageBox::NoButton,QMessageBox::NoButton);
-             this->setEnabled(true);
-             this->setWindowTitle("Themes available on database");
-             dbBackgroundIdsList.clear();
-             m_ui->downloadPushButton->setDisabled(true);
-             m_ui->authorLabel->clear();
-             m_ui->commentTextEdit->clear();
-             m_ui->downloadsLabel->clear();
-             m_ui->nameLabel->clear();
-             m_ui->pictureLabel->setAutoFillBackground(false);
-             m_ui->versionComboBox->clear();
+             if(remoteStartup){
+                 emit themeChoosed(m_ui->nameLabel->text().toLower());
+                 this->close();
+             }
+             else {
+                 this->setEnabled(true);
+                 this->setWindowTitle("Themes available on database");
+                 dbBackgroundIdsList.clear();
+                 m_ui->downloadPushButton->setDisabled(true);
+                 m_ui->authorLabel->clear();
+                 m_ui->commentTextEdit->clear();
+                 m_ui->downloadsLabel->clear();
+                 m_ui->nameLabel->clear();
+                 m_ui->pictureLabel->setAutoFillBackground(false);
+                 m_ui->versionComboBox->clear();
+             }
         }
     }
     if (Id == bgData)
@@ -551,24 +562,30 @@ void ThemeManager::getThemeBackgroundsByIds()
 
          QMessageBox::information(this,"Theme manager","Theme downloaded succesfully.",
                                  QMessageBox::NoButton,QMessageBox::NoButton);
-         this->setEnabled(true);
-         this->setWindowTitle("Themes available on database");
-         themeBgIndex = 0;
-         dbBackgroundIdsList.clear();
-         m_ui->downloadPushButton->setDisabled(true);
-         m_ui->authorLabel->clear();
-         m_ui->commentTextEdit->clear();
-         m_ui->downloadsLabel->clear();
-         m_ui->nameLabel->clear();
-         m_ui->pictureLabel->setAutoFillBackground(false);
-         m_ui->versionComboBox->clear();
-         emit themeLoaded();
+         if(remoteStartup){
+             emit themeChoosed(m_ui->nameLabel->text().toLower());
+             this->close();
+         }
+         else {
+             this->setEnabled(true);
+             this->setWindowTitle("Themes available on database");
+             themeBgIndex = 0;
+             dbBackgroundIdsList.clear();
+             m_ui->downloadPushButton->setDisabled(true);
+             m_ui->authorLabel->clear();
+             m_ui->commentTextEdit->clear();
+             m_ui->downloadsLabel->clear();
+             m_ui->nameLabel->clear();
+             m_ui->pictureLabel->setAutoFillBackground(false);
+             m_ui->versionComboBox->clear();
+             emit themeLoaded();
+         }
 
     }
 }
 void ThemeManager::on_downloadPushButton_clicked()
 {
-    if(m_ui->downloadPushButton->text() == "Download")
+    if(m_ui->downloadPushButton->text() == "Download" || m_ui->downloadPushButton->text() == "Select theme")
     {
         QString version;
         versionFound = false;
@@ -600,23 +617,30 @@ void ThemeManager::on_downloadPushButton_clicked()
                  QMessageBox::NoButton,QMessageBox::NoButton);
                  return;
             }
-            themeToDelete = themeName;
-            QDialog *replace = new QDialog(this);
-            replace->setWindowTitle("Replace theme");
-            replace->resize(800,150);
-            QLabel *label = new QLabel(replace);
-            label->setAlignment(Qt::AlignHCenter);
-            label->setGeometry(0,20,800,45);
-            label->setFont(QFont("sans-serif",14));
-            label->setText("Are you sure you want to replace " + m_ui->listWidget->currentItem()->text() + " version: "
-                            + version + "\nwith version: " + m_ui->versionComboBox->currentText() + "?");
-            QPushButton *replaceButton = new QPushButton(replace);
-            replaceButton->setGeometry(280,75,225,50);
-            replaceButton->setText("Replace");
-            replaceButton->show();
-            connect(replaceButton,SIGNAL(clicked()),replace,SLOT(deleteLater()));
-            connect(replaceButton,SIGNAL(clicked()),this,SLOT(replaceTheme()));
-            replace->exec();
+            // Emit theme name and close dlg.
+            if(remoteStartup){
+                emit themeChoosed(themeName);
+                this->close();
+            }
+            else {
+                themeToDelete = themeName;
+                QDialog *replace = new QDialog(this);
+                replace->setWindowTitle("Replace theme");
+                replace->resize(800,150);
+                QLabel *label = new QLabel(replace);
+                label->setAlignment(Qt::AlignHCenter);
+                label->setGeometry(0,20,800,45);
+                label->setFont(QFont("sans-serif",14));
+                label->setText("Are you sure you want to replace " + m_ui->listWidget->currentItem()->text() + " version: "
+                                + version + "\nwith version: " + m_ui->versionComboBox->currentText() + "?");
+                QPushButton *replaceButton = new QPushButton(replace);
+                replaceButton->setGeometry(280,75,225,50);
+                replaceButton->setText("Replace");
+                replaceButton->show();
+                connect(replaceButton,SIGNAL(clicked()),replace,SLOT(deleteLater()));
+                connect(replaceButton,SIGNAL(clicked()),this,SLOT(replaceTheme()));
+                replace->exec();
+            }
         }
         else
         {
@@ -738,9 +762,9 @@ void ThemeManager::fault(int i,int j,QString string)
 void ThemeManager::loadThemes()
 {
 
-    QDir *themeDirs = new QDir(themesPath);
+    QDir themeDirs(themesPath);
 
-    strList = themeDirs->entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
+    strList = themeDirs.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
     themeDirList = strList;
     deviceThemeCount = strList.count();
 
@@ -1344,3 +1368,15 @@ void ThemeManager::readBgConf(QString line)
              uploadBgName = line.remove(0,5);
          }
 }
+void ThemeManager::setRemoteStartupProperties()
+{
+    remoteStartup = true;
+    m_ui->previousPushButton->hide();
+    m_ui->newPushButton->hide();
+    m_ui->deletePushButton->hide();
+    m_ui->downloadPushButton->setGeometry(275,300,250,70);
+    m_ui->downloadPushButton->setText("Select theme");
+    this->setDisabled(true);
+    this->setWindowTitle("Loading themes on database...");
+    this->getThemeIdsFromDb();
+}
